/* authldap extensions headerfile
   BH 2001030101
*/

#ifndef AUTHLDAP_H
#define AUTHLDAP_H

#include <ldap.h>

#define ALDAP_DEBUG

/* BH 2001040401
 */
typedef struct ldapcon {
	LDAP			*ld;
	int			con;
	char			binddn[256];
	char			bindpasswd[32];
	char			server[64];
	int			last;
	struct ldapcon
					*next;
} LDAPCON;

/*
 * BH 2001063001
 * linked list of mappings between RADIUS attributes and LDAP attributes
 * (structure from freeradius)
 */

typedef struct TLDAP_RADIUS TLDAP_RADIUS;

struct TLDAP_RADIUS {
	char*                 attr;
	char*                 radius_attr;
	struct TLDAP_RADIUS*  next;
};


struct LDAP_s {
	LDAPCON			*user_s;
	LDAPCON			*client_s;
	TLDAP_RADIUS	*check_item_map;
	TLDAP_RADIUS	*reply_item_map;
};

/*
 *	user default LDAP port defined in ldap.h
 *	BH 2001030101
 */
#define ALDAP_PORT LDAP_PORT

#define PRI_ERR 0x8000
#define PRI_WARN 0x0080
#define PRI_NOTE 0x0000

#define ALDAP_ERR_NOERR 0
#define ALDAP_ERR_NOENTRY -1
#define ALDAP_ERR_NOHOST -2
#define ALDAP_ERR_UNKNOWN (-3 - PRI_ERR)
#define ALDAP_ERR_NOMEM (-4 - PRI_ERR)
#define ALDAP_ERR_NOVAL -5
#define ALDAP_ERR_BIND (-6 - PRI_ERR)
#define ALDAP_ERR_NOPASS -7
#define ALDAP_ERR_NOREALM (-8 - PRI_ERR)
#define ALDAP_ERR_TIMEOUT (-9 - PRI_ERR)
#define ALDAP_ERR_RESULT (-10 - PRI_ERR)
#define ALDAP_ERR_RESULTDIFF (-11 - PRI_ERR)
#define ALDAP_ERR_PASS -12
#define ALDAP_ERR_NOUSER -13
#define ALDAP_ERR_SEARCH (-14 - PRI_ERR)
#define ALDAP_ERR_CMP (-15 - PRI_ERR)
#define ALDAP_ERR_INIT (-16 - PRI_ERR)
#define ALDAP_ERR_QTYPE (-17 - PRI_ERR)
#define ALDAP_ERR_CRED (-18 - PRI_ERR)
#define ALDAP_ERR_CMPFALSE -19
#define ALDAP_ERR_NOMEMBER -20
#define ALDAP_ERR_NOCLIENT -21
#define ALDAP_ERR_PMODE (-22 - PRI_ERR)
#define ALDAP_ERR_NOATTR -23
#define ALDAP_ERR_FIRSTENTRY -24
#define ALDAP_ERR_FIRSTATTR -25

/*
#define ALDAP_SRC_FILE 0
#define ALDAP_SRC_LDAP 1
*/

#define ALDAP_QTYPE_USER 0
#define ALDAP_QTYPE_CLIENT 1

#define ALDAP_PASS_READ 0
#define ALDAP_PASS_COMPARE 1

#endif
